@@ -17,6 +17,7 @@ module Foundation.Check.Main
 
 import           Basement.Imports
 import           Basement.IntegralConv
+import           Basement.Cast (cast)
 import           Basement.Bounded
 import           Basement.Types.OffsetSize
 import qualified Basement.Terminal.ANSI as ANSI
@@ -33,7 +34,6 @@ import           Foundation.List.DList
 import           Foundation.Random
 import           Foundation.Monad
 import           Foundation.Monad.State
-import           Control.Monad (when)
 import           Data.Maybe (catMaybes)
 
 nbFail :: TestResult -> HasFailures
@@ -272,8 +272,10 @@ testCheckPlan name actions = do
         then return (GroupResult name 0 (planValidations st) [])
         else do
             displayCurrent name
-            forM_ fails $ \f ->
-                liftIO $ putStrLn $ show f
+            forM_ fails $ \(PropertyResult name' nb r) ->
+                case r of
+                    PropertySuccess  -> whenVerbose $ displayPropertySucceed (name <> ": " <> name') nb
+                    PropertyFailed w -> whenErrorOnly $ displayPropertyFailed (name <> ": " <> name') nb w
             return (GroupResult name (length fails) (planValidations st) fails)
 
 testProperty :: String -> Property -> CheckMain TestResult
@@ -285,7 +287,7 @@ testProperty name prop = do
     params <- getGenParams . config <$> get
     maxTests <- numTests . config <$> get
 
-    (res,nb) <- liftIO $ iterateProperty (CountOf $ integralDownsize (integralCast maxTests :: Int64)) params rngIt prop
+    (res,nb) <- liftIO $ iterateProperty (CountOf $ integralDownsize (cast maxTests :: Int64)) params rngIt prop
     case res of
         PropertyFailed {} -> failed
         PropertySuccess   -> passed
