@@ -1,4 +1,5 @@
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE ConstraintKinds #-}
 module Foundation.Monad.MonadIO
     ( MonadIO(..)
     ) where
@@ -7,9 +8,10 @@ module Foundation.Monad.MonadIO
 import Control.Monad.IO.Class
 #else
 import Basement.Compat.Base
+import Basement.Compat.AMP
 
 -- | Monads in which 'IO' computations may be embedded.
-class Monad m => MonadIO m where
+class AMPMonad m => MonadIO m where
     -- | Lift a computation from the 'IO' monad.
     liftIO :: IO a -> m a
 
